import numpy as np
import argparse
from os import listdir
from os.path import isfile, join
import imageio
import imutils
import cv2

from stitching import Stitcher
from interpolate import linearInterpolateFramesH

if __name__ == '__main__':
	ap = argparse.ArgumentParser()
	ap.add_argument("-f", "--folder",
		help="pasta com as imagens")
	ap.add_argument("-s", "--steps", type=int,
		help="fator de multiplicar numero de frames")
	args = vars(ap.parse_args())

	folder = args["folder"] if args["folder"] is not None else r'samples/ball/football'
	steps = args["steps"] if args["steps"] is not None else 2
	
	dirfiles = [f for f in listdir(folder) if isfile(join(folder, f))]

	stitcher = Stitcher()

	frames = []
	curFrames = None

	# Percorre frames em pares
	for f1,f2 in zip(dirfiles, dirfiles[1:]):
		print(f1,f2)

		img1 = imutils.resize(cv2.imread(join(folder, f1)), width=400)
		img2 = imutils.resize(cv2.imread(join(folder, f2)), width=400)
		res = stitcher.stitch([img2, img1])

		if res is not None:
			(result, H) = res
			curFrames = linearInterpolateFramesH(img1, H, steps=steps, defaultBorder=[255,255,255])
			frames += curFrames[:-1]
		else:
			frames.append(img1)
			curFrames = [img2]

	frames.append(curFrames[-1])

	imageio.mimsave("gif.gif", frames, duration=(0.15/steps))


	# Escreve matriz para matH.txt
	#stitcher = Stitcher()
	#res = stitcher.stitch([imageA, imageB], showMatches=True)